@@ -14,6 +14,19 @@ class Position(StrEnum):
     ATTACKING_MIDFIELDER = "AM"
     CENTRAL_MIDFIELDER = "CM"
     LEFT_MIDFIELDER = "LM"
+    RIGHT_MIDFIELDER = "RM"
+    CENTRAL_MIDFIELDER_LEFT = "CM-L"
+    FORWARD = "F"
+    LEFT_FORWARD = "LF"
+    CENTRE_DEFENDER = "CD"
+    ATTACKING_MIDFIELDER_LEFT = "AM-L"
+    RIGHT_FORWARD = "RF"
+    ATTACKING_MIDFIELDER_RIGHT = "AM-R"
+    SUBSTITUTE = "SUB"
+    CENTRE_MIDFIELDER_RIGHT = "CM-R"
+    DEFENSIVE_MIDFIELDER = "DM"
+    CENTRE_FORWARD_LEFT = "CF-L"
+    CENTRE_FORWARD_RIGHT = "CF-R"
 
 
 _POSITIONS = {str(x): x for x in Position}
